==> nextcloud-app-tasks-0.14.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/zh_HK.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "接下來的任務",
    "Important" : "重要",
    "Today" : "今日",
    "Week" : "本星期",
    "All" : "全部",
    "Current" : "目前",
    "Completed" : "已完成",
    "Tasks" : "任務",
    "The Tasks app for Nextcloud" : "Nextcloud 的任務應用程式",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal, … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "一經啟用，新的「任務」選單將會出現在您 Nextcloud 應用程式選單中。在此，您可以新增與刪除任務、編輯它們的標題、描述、開始與結束日期、標記它們的重要程度。任務可在用戶間分享。任務可使用 CalDav 同步（每個任務列表都會連結到一個 Nextcloud 日曆，用來與您的本機客戶端同步，如 Thunderbird、Evolution、KDE Kontact、iCal 等，只要在您的客戶端中以遠端日曆的形式新增日曆即可）。您可以 ICS 檔案的形式下載您的任務，只要按下每個日曆的下載按鈕就好。",
    "Default list" : "默認清單",
    "Visibility of Smart Collections" : "智慧型收藏的能見度",
    "Hidden" : "隱藏",
    "Visible" : "顯示",
    "Automatic" : "自動",
    "Share with users or groups" : "與用戶或群組分享",
    "No users or groups" : "沒有用戶或群組",
    "Can edit" : "可編輯",
    "Unshare with {displayName}" : "取消與 {displayName} 的分享",
    "Unable to delete the share." : "無法刪除分享。",
    "Unable to change permissions." : "無法更改權限。",
    "Edit" : "編輯",
    "Copy private link" : "複製私人連結",
    "Copied" : "已複製",
    "Cannot copy" : "無法複製",
    "Download" : "下載",
    "Delete" : "刪除",
    "Unshare" : "撤回分享",
    "Cancel" : "取消",
    "Save" : "儲存",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "這將會刪除日曆「{calendar}」與所有對應的活動與任務。",
    "This will unshare the calendar \"{calendar}\"." : "這將會取消日曆「{calendar}」的分享。",
    "This will delete the list \"{list}\" and all corresponding tasks." : "這將會刪除列表「{list}」與所有對應的任務。",
    "This will unshare the list \"{list}\"." : "這將會取消清單「{list}」的分享。",
    "Calendar link copied to clipboard." : "複製日曆連結到剪貼板。",
    "List link copied to clipboard." : "列表連結已複製到剪貼板。",
    "Calendar link could not be copied to clipboard." : "不能複製日曆連結到剪貼板。",
    "List link could not be copied to clipboard." : "連結無法複製到剪貼板。",
    "The name \"{calendar}\" is already used." : "名稱「{calendar}」已被使用。",
    "An empty name is not allowed." : "不允許空白的名稱。",
    "An error occurred, unable to delete the calendar." : "遇到錯誤，無法刪除日曆。",
    "An error occurred, unable to delete the list." : "遇到錯誤，無法刪除列表。",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後刪除日曆"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後取消分享日曆"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["將在 {countdown} 秒後刪除清單"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["將在 {countdown} 秒後取消分享清單"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享了"],
    "Set date" : "設定日期",
    "Set time" : "設定時間",
    "Delete date" : "刪除日期",
    "Click here to add a note." : "單擊此處添加註釋。",
    "Set value" : "設置值",
    "Delete value" : "刪除值",
    "Add this as a new tag" : "將此加入為新標籤",
    "No tag available. Create one!" : "沒有可用的標籤。創建一個！",
    "Delete all completed tasks." : "刪除所有已完成的任務。",
    "Delete completed tasks." : "刪除已完成的任務。",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "從日曆「{calendar}」刪除了所有已完成的任務。",
    "No errors" : "沒有錯誤",
    "Open your browser console for more details" : "開啟您的瀏覽器主控台以取得詳細資訊",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["這將會從日曆「{calendar}」刪除 {taskCount} 個已完成的任務與其子項目。"],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["無法刪除 {failedCount} 個任務。"],
    "Add an important task to \"{calendar}\"…" : "新增重要任務到「{calendar}」……",
    "Add a task due today to \"{calendar}\"…" : "新增今日到期的任務到「{calendar}」…",
    "Add a current task to \"{calendar}\"…" : "新增當前的任務到「{calendar}」…",
    "Add a task to \"{calendar}\"…" : "新增任務到「{calendar}」…",
    "Load all completed tasks." : "載入所有已完成的任務。",
    "Change sort order" : "更改排序",
    "Relevance" : "相關性",
    "Sort by completed state, due date, priority, start date and summary." : "按完成狀態、到期日期、優先程度、開始日期與摘要排序。",
    "Start date" : "開始日期",
    "Sort by start date and summary." : "按開始日期與摘要排序。",
    "Due date" : "到期日期",
    "Sort by due date and summary." : "按到期日與摘要排序。",
    "Created date" : "建立日期",
    "Sort by created date and summary." : "按建立日期與摘要排序。",
    "Last modified" : "最後修改日期",
    "Sort by last-modified date and summary." : "按最後修改日期與摘要排序。",
    "Completed date" : "完成日期",
    "Sort by completed date." : "按完成日期排序。",
    "Priority" : "優先",
    "Sort by priority and summary." : "按優先程度與摘要排序。",
    "Alphabetically" : "字母",
    "Sort by summary and priority." : "按摘要與優先程度排序。",
    "Manually" : "手動",
    "Sort by manual order." : "手動排序。",
    "Task is completed" : "任務已完成",
    "{complete} % completed" : "{complete}% 完成",
    "Task has hidden subtasks" : "任務具有隱藏的子任務",
    "Task is pinned" : "任務被標記為固定",
    "Task has a note" : "任務有註釋",
    "Add subtask" : "新增子任務",
    "Show subtasks" : "顯示子任務",
    "Hide subtasks" : "隱藏子任務",
    "Show closed subtasks" : "顯示已關閉的子任務",
    "Hide closed subtasks" : "隱藏已關閉的子任務",
    "Delete task" : "刪除任務",
    "Toggle starred" : "加上／移除星號",
    "[Yesterday]" : "［昨日］",
    "[Today]" : "［今日］",
    "[Tomorrow]" : "［明日］",
    "[Completed yesterday]" : "[昨日完成]",
    "[Completed today]" : "[今日完成]",
    "[Completed tomorrow]" : "[明日完成]",
    "[Yesterday at] LT" : "[昨日於] LT",
    "[Today at] LT" : "[今日於] LT",
    "[Tomorrow at] LT" : "[明日於] LT",
    "L [at] LT" : "L [於] LT",
    "[Completed yesterday at] LT" : "[昨日完成於] LT",
    "[Completed today at] LT" : "[今日完成於] LT",
    "[Completed tomorrow at] LT" : "[明日完成於] LT",
    "[Completed] L [at] LT" : "[完成] L [於] LT",
    "Add a subtask to \"{task}\"…" : "新增子任務到「{task}」……",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["將在 {countdown} 秒後刪除任務"],
    "Create a new task" : "創建新任務",
    "Create task" : "創建任務",
    "Creating the new task…" : "正在建立新任務...",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" 已被添加至 \"{calendar}\"",
    "Open task" : "打開任務",
    "Close" : " 關閉",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n 項已完成的任務"],
    "Tomorrow" : "明日",
    "Add List…" : "增加清單...",
    "New List" : "新清單",
    "All day" : "整日",
    "Unpin" : "取消固定",
    "Pin" : "固定",
    "Show in Calendar" : "在日曆上顯示",
    "Edit title" : "編輯標題",
    "Details" : "細節",
    "Select a classification" : "選擇等級",
    "Select a status" : "選擇狀態",
    "Select tags" : "選擇標籤",
    "Notes" : "備註",
    "Reminders" : "提醒",
    "Repeat" : "重複",
    "When shared show full event" : "分享的時候顯示完整活動",
    "When shared show only busy" : "分享的時候僅顯示忙碌中",
    "When shared hide this event" : "分享的時候隱藏這個活動",
    "[Completed] L" : "[完成於] L",
    "[Completed last] dddd [at] LT" : "[完成於上] dddd LT",
    "[Completed] dddd [at] LT" : "[完成於] dddd LT",
    "[Last modified yesterday at] LT" : "[最後修改於昨天] LT",
    "[Last modified today at] LT" : "[最後修改於今天] LT",
    "[Last modified] L" : "[最後修改於] L",
    "[Last modified last] dddd [at] LT" : "[最後修改於上] dddd LT",
    "[Last modified] dddd [at] LT" : "[最後修改於] dddd LT",
    "[Created yesterday at] LT" : "[創建於昨天] LT",
    "[Created today at] LT" : "[創建於今天] LT",
    "[Created] L" : "[ 創建於] L",
    "[Created last] dddd [at] LT" : "[創建於上] dddd LT",
    "[Created] dddd [at] LT" : "[創建於] dddd LT",
    "Needs action" : "需要採取行動 ",
    "In process" : "進行中",
    "Canceled" : "已取消",
    "Clear status" : "清空狀態",
    "Loading task from server." : "正在從伺服器載入任務。",
    "Task not found!" : "找不到任務!",
    "[Starts today]" : "[今日開始]",
    "[Starts tomorrow]" : "[昨日開始]",
    "[Starts on] LL" : "[開始於] LL",
    "[Started yesterday]" : "[昨日開始]",
    "[Started on] LL" : "[開始於] LL",
    "[Started today at] LT" : "[今日開始於] LT",
    "[Starts today at] LT" : "[今日開始於] LT",
    "[Starts tomorrow at] LT" : "[明日開始於] LT",
    "[Starts on] LL [at] LT" : "[開始在] LL [於] LT",
    "[Started yesterday at] LT" : "[昨日開始於] LT",
    "[Started on] LL [at] LT" : "[開始在] LL [於] LT",
    "Set start date" : "設定開始日期",
    "[Due today]" : "[今日到期]",
    "[Due tomorrow]" : "[明日到期]",
    "[Due on] LL" : "[到期於] LL",
    "[Was due yesterday]" : "[昨日到期]",
    "[Was due on] LL" : "[到期於] LL",
    "[Was due today at] LT" : "[今日到期於] LT",
    "[Due today at] LT" : "[今日到期於] LT",
    "[Due tomorrow at] LT" : "[明日到期於] LT",
    "[Due on] LL [at] LT" : "[到期於] LL LT",
    "[Was due yesterday at] LT" : "[昨日到期於] LT",
    "[Was due on] LL [at] LT" : "[到期在於] LL LT",
    "Set due date" : "設定到期日期",
    "Priority {priority}: low" : "優先程度 {priority}：低",
    "Priority {priority}: medium" : "優先程度 {priority}：中",
    "Priority {priority}: high" : "優先程度 {priority}：高",
    "No priority assigned" : "未指定優先程度",
    "{percent} % completed" : "{percent}% 完成",
    "No upcoming tasks" : "沒有快將到期的任務",
    "upcoming tasks" : "接下來的任務",
    "No tasks today" : "今日沒有任務",
    "Successfully created the task." : "成功建立任務。",
    "Could not delete the task." : "無法刪除任務。",
    "Synchronizing to the server." : "與伺服器同步。",
    "Task successfully saved to server." : "任務已成功儲存到伺服器。",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "無法更新任務，因為其在伺服器上已變更。請點擊以重新整理，近端變更將會被丟棄。",
    "Could not update the task." : "無法更新任務。",
    "Successfully updated the task." : "成功更新任務。",
    "Task successfully moved to new calendar." : "任務成功移到新的日曆。",
    "An error occurred" : "發生錯誤",
    "Create a task" : "創建任務",
    "Message from {author} in {conversationName}" : "{conversationName} 中來自 {author} 之訊息"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.14.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/zh_HK.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "接下來的任務",
    "Important" : "重要",
    "Today" : "今日",
    "Week" : "本星期",
    "All" : "全部",
    "Current" : "目前",
    "Completed" : "已完成",
    "Tasks" : "任務",
    "The Tasks app for Nextcloud" : "Nextcloud 的任務應用程式",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "一經啟用，新的「任務」選單將會出現在您 Nextcloud 應用程式選單中。在此，您可以新增與刪除任務、編輯它們的標題、描述、開始與結束日期、標記它們的重要程度。任務可在用戶間分享。任務可使用 CalDav 同步（每個任務列表都會連結到一個 Nextcloud 日曆，用來與您的本機客戶端同步，如 Thunderbird、Evolution、KDE Kontact、iCal 等，只要在您的客戶端中以遠端日曆的形式新增日曆即可）。您可以 ICS 檔案的形式下載您的任務，只要按下每個日曆的下載按鈕就好。",
    "Default list" : "默認清單",
    "Visibility of Smart Collections" : "智慧型收藏的能見度",
    "Hidden" : "隱藏",
    "Visible" : "顯示",
    "Automatic" : "自動",
    "Share with users or groups" : "與用戶或群組分享",
    "No users or groups" : "沒有用戶或群組",
    "Can edit" : "可編輯",
    "Unshare with {displayName}" : "取消與 {displayName} 的分享",
    "Unable to delete the share." : "無法刪除分享。",
    "Unable to change permissions." : "無法更改權限。",
    "Edit" : "編輯",
    "Copy private link" : "複製私人連結",
    "Copied" : "已複製",
    "Cannot copy" : "無法複製",
    "Export" : "導出",
    "Delete" : "刪除",
    "Unshare" : "撤回分享",
    "Cancel" : "取消",
    "Save" : "儲存",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "這將會刪除日曆「{calendar}」與所有對應的活動與任務。",
    "This will unshare the calendar \"{calendar}\"." : "這將會取消日曆「{calendar}」的分享。",
    "This will delete the list \"{list}\" and all corresponding tasks." : "這將會刪除列表「{list}」與所有對應的任務。",
    "This will unshare the list \"{list}\"." : "這將會取消清單「{list}」的分享。",
    "Calendar link copied to clipboard." : "複製日曆連結到剪貼板。",
    "List link copied to clipboard." : "列表連結已複製到剪貼板。",
    "Calendar link could not be copied to clipboard." : "不能複製日曆連結到剪貼板。",
    "List link could not be copied to clipboard." : "連結無法複製到剪貼板。",
    "The name \"{calendar}\" is already used." : "名稱「{calendar}」已被使用。",
    "An empty name is not allowed." : "不允許空白的名稱。",
    "An error occurred, unable to delete the calendar." : "遇到錯誤，無法刪除日曆。",
    "An error occurred, unable to delete the list." : "遇到錯誤，無法刪除列表。",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後刪除日曆"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後取消分享日曆"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["將在 {countdown} 秒後刪除清單"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["將在 {countdown} 秒後取消分享清單"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享了"],
    "Trash bin" : "回收桶",
    "Loading deleted calendars, tasks and events." : "加載已刪除的日曆、任務和活動。",
    "You do not have any deleted calendars, tasks or events." : "您沒有任何已刪除的日曆、任務和活動。",
    "Name" : "姓名",
    "Deleted" : "已刪除",
    "Restore" : "復原",
    "Delete permanently" : "永久刪除",
    "Empty trash bin" : "清空回收桶",
    "Untitled task" : "未命名任務",
    "Untitled event" : "無標題活動",
    "Untitled journal" : "未命名日誌",
    "Untitled item" : "無題項目",
    "Unknown calendar" : "日曆不詳",
    "Could not load deleted calendars and objects" : "無法加載已刪除的日曆和物件",
    "Could not delete calendar or event" : "無法刪除日曆或活動",
    "Could not restore calendar or event" : "無法復原日曆或活動",
    "Do you really want to empty the trash bin?" : "您真的想要清空回收桶嗎？",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["回收桶中的項目會在 {numDays} 天後被刪除"],
    "Select a calendar" : "選擇日曆",
    "No calendar matches the search." : "沒有日曆與搜尋匹配。",
    "Set date" : "設定日期",
    "Set time" : "設定時間",
    "Delete date" : "刪除日期",
    "Click here to add a note." : "單擊此處添加註釋。",
    "Set value" : "設置值",
    "Delete value" : "刪除值",
    "Add this as a new tag" : "將此加入為新標籤",
    "No tag available. Create one!" : "沒有可用的標籤。創建一個！",
    "Delete all completed tasks." : "刪除所有已完成的任務。",
    "Delete completed tasks." : "刪除已完成的任務。",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "從日曆「{calendar}」刪除了所有已完成的任務。",
    "No errors" : "沒有錯誤",
    "Open your browser console for more details" : "開啟您的瀏覽器主控台以取得詳細資訊",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["這將會從日曆「{calendar}」刪除 {taskCount} 個已完成的任務與其子項目。"],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["無法刪除 {failedCount} 個任務。"],
    "Add an important task to \"{calendar}\"…" : "新增重要任務到「{calendar}」……",
    "Add a task due today to \"{calendar}\"…" : "新增今日到期的任務到「{calendar}」…",
    "Add a current task to \"{calendar}\"…" : "新增當前的任務到「{calendar}」…",
    "Add a task to \"{calendar}\"…" : "新增任務到「{calendar}」…",
    "Load all completed tasks." : "載入所有已完成的任務。",
    "Change sort order" : "更改排序",
    "Relevance" : "相關性",
    "Sort by completed state, due date, priority, start date and summary." : "按完成狀態、到期日期、優先程度、開始日期與摘要排序。",
    "Start date" : "開始日期",
    "Sort by start date and summary." : "按開始日期與摘要排序。",
    "Due date" : "到期日期",
    "Sort by due date and summary." : "按到期日與摘要排序。",
    "Created date" : "建立日期",
    "Sort by created date and summary." : "按建立日期與摘要排序。",
    "Last modified" : "最後修改日期",
    "Sort by last-modified date and summary." : "按最後修改日期與摘要排序。",
    "Completed date" : "完成日期",
    "Sort by completed date." : "按完成日期排序。",
    "Priority" : "優先",
    "Sort by priority and summary." : "按優先程度與摘要排序。",
    "Alphabetically" : "字母",
    "Sort by summary and priority." : "按摘要與優先程度排序。",
    "Manually" : "手動",
    "Sort by manual order." : "手動排序。",
    "{complete} % completed" : "{complete}% 完成",
    "Task has hidden subtasks" : "任務具有隱藏的子任務",
    "Task is pinned" : "任務被標記為固定",
    "Task has a note" : "任務有註釋",
    "Add subtask" : "新增子任務",
    "Show subtasks" : "顯示子任務",
    "Hide subtasks" : "隱藏子任務",
    "Show closed subtasks" : "顯示已關閉的子任務",
    "Hide closed subtasks" : "隱藏已關閉的子任務",
    "Delete task" : "刪除任務",
    "Toggle starred" : "加上／移除星號",
    "[Yesterday]" : "［昨日］",
    "[Today]" : "［今日］",
    "[Tomorrow]" : "［明日］",
    "[Completed yesterday]" : "[昨日完成]",
    "[Completed today]" : "[今日完成]",
    "[Completed tomorrow]" : "[明日完成]",
    "[Yesterday at] LT" : "[昨日於] LT",
    "[Today at] LT" : "[今日於] LT",
    "[Tomorrow at] LT" : "[明日於] LT",
    "L [at] LT" : "L [於] LT",
    "[Completed yesterday at] LT" : "[昨日完成於] LT",
    "[Completed today at] LT" : "[今日完成於] LT",
    "[Completed tomorrow at] LT" : "[明日完成於] LT",
    "[Completed] L [at] LT" : "[完成] L [於] LT",
    "Add a subtask to \"{task}\"…" : "新增子任務到「{task}」……",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["將在 {countdown} 秒後刪除任務"],
    "Task is cancelled" : "任務已取消",
    "Task is completed" : "任務已完成",
    "Task is read-only" : "任務是唯讀的",
    "Task is not completed" : "任務未完成",
    "Create a new task" : "創建新任務",
    "Task summary" : "任務摘要",
    "Create task" : "創建任務",
    "Creating the new task…" : "正在建立新任務...",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" 已被添加至 \"{calendar}\"",
    "Open task" : "打開任務",
    "Close" : " 關閉",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n 項已完成的任務"],
    "Tomorrow" : "明日",
    "Add List…" : "增加清單...",
    "New List" : "新清單",
    "All day" : "整日",
    "Unpin" : "取消固定",
    "Pin" : "固定",
    "Show in Calendar" : "在日曆上顯示",
    "Edit title" : "編輯標題",
    "Details" : "細節",
    "Select a classification" : "選擇等級",
    "Select a status" : "選擇狀態",
    "Select tags" : "選擇標籤",
    "Notes" : "備註",
    "Reminders" : "提醒",
    "Repeat" : "重複",
    "When shared show full event" : "分享的時候顯示完整活動",
    "When shared show only busy" : "分享的時候僅顯示忙碌中",
    "When shared hide this event" : "分享的時候隱藏這個活動",
    "[Completed] L" : "[完成於] L",
    "[Completed last] dddd [at] LT" : "[完成於上] dddd LT",
    "[Completed] dddd [at] LT" : "[完成於] dddd LT",
    "[Last modified yesterday at] LT" : "[最後修改於昨天] LT",
    "[Last modified today at] LT" : "[最後修改於今天] LT",
    "[Last modified] L" : "[最後修改於] L",
    "[Last modified last] dddd [at] LT" : "[最後修改於上] dddd LT",
    "[Last modified] dddd [at] LT" : "[最後修改於] dddd LT",
    "[Created yesterday at] LT" : "[創建於昨天] LT",
    "[Created today at] LT" : "[創建於今天] LT",
    "[Created] L" : "[ 創建於] L",
    "[Created last] dddd [at] LT" : "[創建於上] dddd LT",
    "[Created] dddd [at] LT" : "[創建於] dddd LT",
    "Needs action" : "需要採取行動 ",
    "In process" : "進行中",
    "Canceled" : "已取消",
    "Clear status" : "清空狀態",
    "Loading task from server." : "正在從伺服器載入任務。",
    "Task not found!" : "找不到任務!",
    "[Starts today]" : "[今日開始]",
    "[Starts tomorrow]" : "[昨日開始]",
    "[Starts on] LL" : "[開始於] LL",
    "[Started yesterday]" : "[昨日開始]",
    "[Started on] LL" : "[開始於] LL",
    "[Started today at] LT" : "[今日開始於] LT",
    "[Starts today at] LT" : "[今日開始於] LT",
    "[Starts tomorrow at] LT" : "[明日開始於] LT",
    "[Starts on] LL [at] LT" : "[開始在] LL [於] LT",
    "[Started yesterday at] LT" : "[昨日開始於] LT",
    "[Started on] LL [at] LT" : "[開始在] LL [於] LT",
    "Set start date" : "設定開始日期",
    "[Due today]" : "[今日到期]",
    "[Due tomorrow]" : "[明日到期]",
    "[Due on] LL" : "[到期於] LL",
    "[Was due yesterday]" : "[昨日到期]",
    "[Was due on] LL" : "[到期於] LL",
    "[Was due today at] LT" : "[今日到期於] LT",
    "[Due today at] LT" : "[今日到期於] LT",
    "[Due tomorrow at] LT" : "[明日到期於] LT",
    "[Due on] LL [at] LT" : "[到期於] LL LT",
    "[Was due yesterday at] LT" : "[昨日到期於] LT",
    "[Was due on] LL [at] LT" : "[到期在於] LL LT",
    "Set due date" : "設定到期日期",
    "Priority {priority}: low" : "優先程度 {priority}：低",
    "Priority {priority}: medium" : "優先程度 {priority}：中",
    "Priority {priority}: high" : "優先程度 {priority}：高",
    "No priority assigned" : "未指定優先程度",
    "{percent} % completed" : "{percent}% 完成",
    "No upcoming tasks" : "沒有快將到期的任務",
    "upcoming tasks" : "接下來的任務",
    "No tasks today" : "今日沒有任務",
    "Mark as done" : "標記為完成",
    "No due date assigned" : "未指定截止日期",
    "[Due yesterday]" : "[昨天截止]",
    "[Due] L" : "[截止於] L",
    "[Due yesterday at] LT" : "[截止時間為昨天] LT",
    "[Due] L [at] LT" : "[截止於] L LT",
    "Successfully created the task." : "成功建立任務。",
    "Could not delete the task." : "無法刪除任務。",
    "Synchronizing to the server." : "與伺服器同步。",
    "Task successfully saved to server." : "任務已成功儲存到伺服器。",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "無法更新任務，因為其在伺服器上已變更。請點擊以重新整理，近端變更將會被丟棄。",
    "Could not update the task." : "無法更新任務。",
    "Successfully updated the task." : "成功更新任務。",
    "Task successfully moved to new calendar." : "任務成功移到新的日曆。",
    "An error occurred" : "發生錯誤",
    "Create a task" : "創建任務",
    "Message from {author} in {conversationName}" : "{conversationName} 中來自 {author} 之訊息"
},
"nplurals=1; plural=0;");
